Index: trunk/src/series/merge_proj.m
===================================================================
--- trunk/src/series/merge_proj.m	(revision 1113)
+++ trunk/src/series/merge_proj.m	(revision 1114)
@@ -113,5 +113,5 @@
 RootFile=Param.InputTable(:,3);
 SubDir=Param.InputTable(:,2);
-NomType=Param.InputTable(:,4);
+% NomType=Param.InputTable(:,4);
 FileExt=Param.InputTable(:,5);
 
Index: trunk/src/series/time_series.m
===================================================================
--- trunk/src/series/time_series.m	(revision 1113)
+++ trunk/src/series/time_series.m	(revision 1114)
@@ -214,12 +214,15 @@
 
 %% coordinate transform or other user defined transform
-transform_fct=[];%default
+transform_fct='';%default fct handle
 if isfield(Param,'FieldTransform')&&~isempty(Param.FieldTransform.TransformName)
-    %addpath(Param.FieldTransform.TransformPath)
+    currentdir=pwd;
+    cd(Param.FieldTransform.TransformPath)
     transform_fct=str2func(Param.FieldTransform.TransformName);
-    %rmpath(Param.FieldTransform.TransformPath)
+    cd (currentdir)
     if isfield(Param,'TransformInput')
-        XmlData{1}.TransformInput=Param.TransformInput;
-    end
+        for iview=1:NbView
+            XmlData{iview}.TransformInput=Param.TransformInput;
+        end
+    end       
 end
 

Index: trunk/src/series/sliding_average.m
===================================================================
--- trunk/src/series/sliding_average.m	(revision 1113)
+++ trunk/src/series/sliding_average.m	(revision 1114)
@@ -16,5 +16,5 @@
 % Param contains the elements:(use the menu bar command 'export/GUI config' in series to 
 % see the current structure Param)
 %    .InputTable: cell of input file names, (several lines for multiple input)
 %                      each line decomposed as {RootPath,SubDir,Rootfile,NomType,Extension}
 %    .OutputSubDir: name of the subdirectory for data outputs
@@ -179,10 +179,10 @@
 if isfield(Param,'InputFields')
     InputFields{1}=Param.InputFields;
-end
+end5.804
 
 nbfiles=0;
 nbmissing=0;
 
-%% initialisation
+%% initialisation manip Coriolis
 char_index=regexp(SubDir{1},'waves_L1_');
 switch(SubDir{1}(char_index+9))
@@ -242,5 +242,5 @@
         break
     end
-    [Field,tild,errormsg] = read_field(filecell{1,index},FileType{iview},InputFields{iview},frame_index{iview}(index));
+    [Field,tild,~] = read_field(filecell{1,index},FileType{iview},InputFields{iview},frame_index{iview}(index));
     
     %%%%%%%%%%% MAIN RUNNING OPERATIONS  %%%%%%%%%%%%
@@ -16,5 +16,5 @@
 % Param contains the elements:(use the menu bar command 'export/GUI config' in series to 
 % see the current structure Param)
-%    .InputTable: cell of input file names, (several lines for multiple input)
+%    .InputTable: cell of input file names, (several5.804 lines for multiple input)
 %                      each line decomposed as {RootPath,SubDir,Rootfile,NomType,Extension}
 %    .OutputSubDir: name of the subdirectory for data outputs